Technical reference
*******************

.. _regionalization-mixin:

Regionalization base class
==========================

.. autoclass:: bw2regional.lca.base_class.RegionalizationBase
    :members:

.. _two-scales-with-loading:

Two spatial scales with generic loading
=======================================

.. autoclass:: bw2regional.lca.TwoSpatialScalesWithGenericLoadingLCA
    :members:

.. _two-scales:

Two spatial scales
==================

.. autoclass:: bw2regional.lca.TwoSpatialScalesLCA
    :members:

.. _one-scale:

Shared spatial scale
====================

.. autoclass:: bw2regional.lca.OneSpatialScaleLCA
    :members:

.. _xtables:

Extension tables
================

.. autoclass:: bw2regional.lca.ExtensionTablesLCA
    :members:

Topographies
============

.. autoclass:: bw2regional.topography.Topography
    :members:
